#!/bin/bash

cd `dirname $0`
MYDIR=`pwd`
MYSCRIPT=`basename $0`
cd ../..
S2P_PATH_BASE=`pwd`
cd $MYDIR

S2P_OS_USERNAME=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^os.username | cut -d= -f2`
if [[ `whoami` != "$S2P_OS_USERNAME" ]]; then
	exec sudo -u $S2P_OS_USERNAME ./$MYSCRIPT $@
fi

usage()
{
	echo "Usage: $0 username start|stop"
	cd $OWD

	exit -1
}

do_lock()
{
	if mkdir /tmp/s2p-start-$1.lock; then
		return 0
	else
		echo "Account is locked."
		$S2P_PATH_BASE/core/libexec/write_log.py sess.$1 info "Issued a stop/restart while session is locked"
		exit 1
	fi
}

do_unlock()
{
	rmdir /tmp/s2p-start-$1.lock &> /dev/null
}

if [ -z "$1" ]; then
	usage
fi

if [ "$2" == "restart" ]; then
	$S2P_PATH_BASE/core/bin/session.sh $1 stop $3
	$S2P_PATH_BASE/core/bin/session.sh $1 start $3
	exit 0
fi

do_lock $1

# Rimozione flag di riavvio
sed -i "s/^$1\$//" $S2P_PATH_BASE/core/flags/sessions.restart.flag &> /dev/null

if [ "$2" == "start" ]; then
	IS_ALREADY_RUNNING=`$S2P_PATH_BASE/core/libexec/list_running.py|grep ^$1$ -c`
	
	if [ "$IS_ALREADY_RUNNING" -lt "1" ]; then

		modprobe snd-dummy enable=1,1,1,1,1,1,1,1 &> /dev/null
		chmod 666 /dev/snd/* &> /dev/null

		$S2P_PATH_BASE/core/libexec/session/halt.py $1 $3 s&> /dev/null
		$S2P_PATH_BASE/core/libexec/session/prepare.py $1 $3 &> /dev/null
		($S2P_PATH_BASE/core/libexec/session/run.py $1 $3 &) &> /dev/null
	
	else
		echo "This account is already running."
		do_unlock $1
		
		exit 1
	fi

elif [ "$2" == "stop" ]; then
	$S2P_PATH_BASE/core/libexec/session/halt.py $1 $3 &> /dev/null

else
	do_unlock $1
	usage

fi

do_unlock $1
exit 0
