#!/bin/bash

cd `dirname $0`
MYDIR=`pwd`
MYSCRIPT=`basename $0`
cd ../..
S2P_PATH_BASE=`pwd`
cd $MYDIR

MIN_STACK_SIZE=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^tuning.ulimit.min-stack-size | cut -d= -f2`
MAX_OPEN_FILES=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^tuning.ulimit.max-open-files | cut -d= -f2`
CORE_DUMPS=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^tuning.ulimit.core-dumps | cut -d= -f2`

S2P_PATH_SOCKS=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^path.socks | cut -d= -f2`
S2P_PATH_RUN=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^path.run | cut -d= -f2`
S2P_PATH_LOG=`$S2P_PATH_BASE/core/libexec/config_view.py system simple | grep ^path.log | cut -d= -f2`

if [ "$1" == "restart" ]; then
	./$MYSCRIPT stop $2
	./$MYSCRIPT start $2
	exit 0
fi

# Needed files and folders
mkdir -p $S2P_PATH_RUN &> /dev/null
mkdir -p $S2P_PATH_LOG &> /dev/null
mkdir -p $S2P_PATH_SOCKS &> /dev/null
touch $S2P_PATH_LOG/full.log

# Ulimit tuning
ulimit -s $MIN_STACK_SIZE
ulimit -n $MAX_OPEN_FILES

# Hope we will not need this
if [ "$CORE_DUMPS" == "true" ]; then
	ulimit -c unlimited &> /dev/null
	echo "$S2P_PATH_BASE/core/tmp/core" > /proc/sys/kernel/core_pattern
	echo "1" > /proc/sys/kernel/core_uses_pid
else
	ulimit -S -c 0  &> /dev/null
fi

# Rock'n'roll
$S2P_PATH_BASE/core/bin/set_permissions.sh &> /dev/null
$S2P_PATH_BASE/core/bin/logger.sh start &> /dev/null

# Configure packages
$S2P_PATH_BASE/core/bin/check_packages.sh &> /dev/null

$S2P_PATH_BASE/core/libexec/write_log.py sys info "Setting min-stack-size: $MIN_STACK_SIZE"
$S2P_PATH_BASE/core/libexec/write_log.py sys info "Setting max-open-files: $MAX_OPEN_FILES"

if [ "$1" == "start" ]; then

	$S2P_PATH_BASE/core/libexec/write_log.py sys info "Starting system"
	$S2P_PATH_BASE/core/bin/configure.sh &> /dev/null
	$S2P_PATH_BASE/core/bin/resources_monitor.sh start &> /dev/null
	$S2P_PATH_BASE/core/bin/channels_manager.sh start &> /dev/null
 	$S2P_PATH_BASE/core/bin/sessions_manager.sh start &> /dev/null

	if [ "$2" == "fast" ]; then
		($S2P_PATH_BASE/core/bin/sessions.sh start &) &> /dev/null
	else
 		$S2P_PATH_BASE/core/bin/sessions.sh start &> /dev/null
	fi

 	$S2P_PATH_BASE/core/bin/applications.sh start &> /dev/null
 	$S2P_PATH_BASE/core/bin/esp.sh start &> /dev/null
 	
 	$S2P_PATH_BASE/core/libexec/write_log.py sys info "System started"

elif [ "$1" == "stop" ]; then

	$S2P_PATH_BASE/core/libexec/write_log.py sys info "Stopping system"

	$S2P_PATH_BASE/core/bin/esp.sh stop &> /dev/null
	$S2P_PATH_BASE/core/bin/applications.sh stop &> /dev/null
 	$S2P_PATH_BASE/core/bin/sessions.sh stop &> /dev/null
 	$S2P_PATH_BASE/core/bin/sessions_manager.sh stop &> /dev/null
	$S2P_PATH_BASE/core/bin/channels_manager.sh stop &> /dev/null
	$S2P_PATH_BASE/core/bin/resources_monitor.sh stop &> /dev/null

	$S2P_PATH_BASE/core/libexec/write_log.py sys info "System stopped"
	$S2P_PATH_BASE/core/bin/logger.sh stop &> /dev/null

	rm -f $S2P_PATH_BASE/core/flags/*.flag &> /dev/null
	rm -f $S2P_PATH_RUN/*.pid &> /dev/null

fi
